# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ocx', 'ocx.ocx_286', 'ocx.ocx_300a0']

package_data = \
{'': ['*']}

install_requires = \
['packaging>=23.1,<24.0', 'xsdata>=23.6,<24.0']

setup_kwargs = {
    'name': 'ocx',
    'version': '3.0.0a0',
    'description': '',
    'long_description': '![3DOCX.org logo](./docs/_static/logo.png)\n# The Open Class 3D Exchange (OCX) Schema\n\n## Introduction \nThis is the official GitHub repository for the Open Class 3D Exchange (OCX) schema (working draft version) owned and managed by the [OCX Consortium](https://3Docx.org).  \nThe latest published version of the OCX schema is available from the consortium\'s website.\n\n## Changelog\n  * [CHANGELOG.md](CHANGELOG.md)\n\n## Historic changes (pre 2.8.6)\n\n  * [PRERELEASE_CHANGELOG.md](PRERELEASE_CHANGELOG.md)\n\n## How to contribute\nThe schema file is maintained using an XML editor like Altova XMLSpy.\n1. Installation: Simply download the schema files from the repository or clone it using git.\n2. Create an [Issue](https://docs.github.com/en/issues/tracking-your-work-with-issues/creating-an-issue) for the proposed schema change. \nFollow [the recipe on the Wiki](https://github.com/OCXStandard/OCX_Schema/wiki) on how to register an issue.\n3. Then create a branch from the issue, check out the branch and implement the proposed changes.\n4. When the implementation is completed, create a [pull request](https://docs.github.com/en/pull-requests/collaborating-with-pull-requests/proposing-changes-to-your-work-with-pull-requests/about-pull-requests).\n4. The pull request will have to be approved by the [OCXStandard maintainer](https://github.com/orgs/OCXStandard/teams/ocx-schema-team?query=role%3Amaintainer) before it can be included in the working draft.\n\n\n## Schema versioning\nWe are using [semantic versioning (semver)](https://semver.org/) to version the OCX schema. A published schema verison follows the semver pattern on the form X.Y.Z where X, Y, and Z are non-negative integers, and MUST NOT contain leading zeroes. \nX is the major version, Y is the minor version, and Z is the patch version. Each element MUST increase numerically. For instance: 1.9.0 -> 1.10.0 -> 1.11.0. \n\nA pre-release version is denoted by appending a hyphen and a pre-release identifier (alpha, beta ...) immediately following the patch version, for example: 3.0.0-alpha\n\nIf a pre-release tag needs to be patched, append a letter to the tag separated with an underscore, eg. 3.0.0-alpha_b.  Do not use ``.`` (dot) as separator.\n\n## ``tbump`` versioning tool\n\nThe Python [``tbump``](https://pypi.org/project/tbump/) tool is used to automate and bump schema versions. tbump also provides the possibility for pre- and post-commit actions.\nThe project config file ``pyproject.toml`` contains the tbump settings.\n\n### Usage\n\nAssume that the current schema version is ``2.8.6``. To bump the schema version to the pre-release ``alpha`` version, the following command can be issued:\n\n<pre><code>\n> tbump 3.0.0-alpha\n:: Bumping from 2.8.6 to 3.0.0-alpha\n=> Would update current version in pyproject.toml\n=> Would patch these files\n- pyproject.toml:3 version = "2.8.6"\n+ pyproject.toml:3 version = "3.0.0-alpha"\n- pyproject.toml:34 current = "2.8.6"\n+ pyproject.toml:34 current = "3.0.0-alpha"\n- OCX_Schema.xsd:103 <xs:attribute name="schemaVersion" type="xs:string" use="required" fixed="2.8.6">\n+ OCX_Schema.xsd:103 <xs:attribute name="schemaVersion" type="xs:string" use="required" fixed="3.0.0-alpha">\n- OCX_Schema.xsd:12 xmlns:ocx="https://3docx.org/fileadmin//ocx_schema//V286//OCX_Schema.xsd"\n+ OCX_Schema.xsd:12 xmlns:ocx="https://3docx.org/fileadmin//ocx_schema//V300alpha//OCX_Schema.xsd"\n- OCX_Schema.xsd:14 targetNamespace="https://3docx.org/fileadmin//ocx_schema//V286//OCX_Schema.xsd"\n+ OCX_Schema.xsd:14 targetNamespace="https://3docx.org/fileadmin//ocx_schema//V300alpha//OCX_Schema.xsd"\n=> Would run these hooks before commit\n* (1/4) $ python xsdata_package.py 3.0.0-alpha\n* (2/4) $ xsdata generate OCX_Schema.xsd\n* (3/4) $ gid add ./ocx_*\n* (4/4) $ python insert_version.py 3.0.0-alpha\n=> Would run these git commands\n$ git add --update\n$ git commit --message Bump to 3.0.0-alpha\n$ git tag --annotate --message v3.0.0-alpha v3.0.0-alpha\n$ git push --atomic origin working_draft v3.0.0-alpha\n:: Looking good? (y/N)\n>\n</code></pre>\n\n\n\n\n## Naive databinding\nA set of Python dataclasses are autogenerated after each version release, see [databindings](databinding.rst)\n\n## OCX Public License\nThe OCX standard is governed by the 3Docx.org (https://3Docx.org) Consortium Members and published under the\nApache 2.0 Public License conditions (the License).\n\nYou may obtain a copy of the License at:\n\n[LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\nUnless required by applicable law or agreed to in writing, the 3Docx standard and software distributed under the License\nis distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nThe OCX Consortium is not liable to any use whatsoever of the distributed standard or software based on the standard.\n\nSee the License for the specific language governing permissions and limitations under the License.\n',
    'author': 'ocastrup',
    'author_email': 'ole.christain.astrup@dnv.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
